@@ -5,6 +5,7 @@
 #include <Python.h>
 #include <pygobject.h>
 #include <pygtk/pygtk.h>
+#include <bonobo/bonobo-ui-main.h>
 
 /* include any extra headers needed here */
 
@@ -35,7 +36,4 @@ initui(void)
     pybonoboui_register_classes(d);
 
     /* add anything else to the module dictionary (such as constants) */
-
-    if (PyErr_Occurred())
-        Py_FatalError("could not initialise module ui");
 }
